@@ -6,7 +6,7 @@ from fief_client import FiefAsync
 
 from fief.dependencies.admin_session import get_userinfo
 from fief.dependencies.fief import get_fief
-from fief.dependencies.global_managers import get_admin_session_token_manager
+from fief.dependencies.main_managers import get_admin_session_token_manager
 from fief.managers import AdminSessionTokenManager
 from fief.models import AdminSessionToken
 from fief.settings import settings
