@@ -3,7 +3,7 @@ from fief.models.account_user import AccountUser
 from fief.models.admin_api_key import AdminAPIKey
 from fief.models.admin_session_token import AdminSessionToken
 from fief.models.authorization_code import AuthorizationCode
-from fief.models.base import AccountBase, GlobalBase
+from fief.models.base import AccountBase, MainBase
 from fief.models.client import Client
 from fief.models.generics import M_UUID, M
 from fief.models.grant import Grant
@@ -21,9 +21,9 @@ __all__ = [
     "AdminSessionToken",
     "AuthorizationCode",
     "Client",
-    "GlobalBase",
     "Grant",
     "LoginSession",
+    "MainBase",
     "RefreshToken",
     "SessionToken",
     "M",
