@@ -3,11 +3,11 @@ from sqlalchemy import Column, ForeignKey
 from sqlalchemy.orm import relationship
 
 from fief.models.account import Account
-from fief.models.base import GlobalBase
+from fief.models.base import MainBase
 from fief.models.generics import GUID, CreatedUpdatedAt, UUIDModel
 
 
-class AccountUser(UUIDModel, CreatedUpdatedAt, GlobalBase):
+class AccountUser(UUIDModel, CreatedUpdatedAt, MainBase):
     __tablename__ = "account_users"
 
     account_id: UUID4 = Column(GUID, ForeignKey(Account.id, ondelete="CASCADE"), nullable=False)  # type: ignore
