@@ -4,11 +4,11 @@ from pydantic import UUID4
 from sqlalchemy import Column, ForeignKey, String
 
 from fief.models.account import Account
-from fief.models.base import GlobalBase
+from fief.models.base import MainBase
 from fief.models.generics import GUID, CreatedUpdatedAt, UUIDModel
 
 
-class AdminAPIKey(UUIDModel, CreatedUpdatedAt, GlobalBase):
+class AdminAPIKey(UUIDModel, CreatedUpdatedAt, MainBase):
     __tablename__ = "admin_api_key"
 
     name: str = Column(String(length=255), nullable=False)
